@@ -1,3 +1,3 @@
-'''import all'''
+'''initialize'''
 from .utils import *
 from .sources import *
\ No newline at end of file
