@@ -1,11 +1,14 @@
-'''import all'''
+'''initialize'''
+from .ted import Ted
 from .cntv import CNTV
 from .mgtv import MGTV
 from .migu import Migu
+from .pipix import Pipix
 from .acfun import AcFun
 from .zhihu import Zhihu
 from .xigua import Xigua
 from .iqiyi import Iqiyi
 from .douyin import Douyin
 from .haokan import Haokan
-from .bilibili import Bilibili
\ No newline at end of file
+from .bilibili import Bilibili
+from .pipigaoxiao import Pipigaoxiao
\ No newline at end of file
