@@ -1,4 +1,4 @@
-'''import all'''
+'''initialize'''
 from .downloader import Downloader
 from .logger import Logger, printTable
 from .misc import checkDir, seconds2hms, loadConfig, filterBadCharacter
\ No newline at end of file
